@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.DatabaseMigrationService 1.23.0\nVersion:        "
-        " 1.23.0.post1\nBuilder version: 7.5.14\nDocs:           "
+        "Type annotations for boto3.DatabaseMigrationService 1.24.5\nVersion:        "
+        " 1.24.5\nBuilder version: 7.6.1\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.23.0.post1")
+    print("1.24.5")
 
 
 def main() -> None:
