@@ -47,6 +47,7 @@ from .type_defs import (
     CancelReplicationTaskAssessmentRunResponseTypeDef,
     CreateEndpointResponseTypeDef,
     CreateEventSubscriptionResponseTypeDef,
+    CreateFleetAdvisorCollectorResponseTypeDef,
     CreateReplicationInstanceResponseTypeDef,
     CreateReplicationSubnetGroupResponseTypeDef,
     CreateReplicationTaskResponseTypeDef,
@@ -54,6 +55,7 @@ from .type_defs import (
     DeleteConnectionResponseTypeDef,
     DeleteEndpointResponseTypeDef,
     DeleteEventSubscriptionResponseTypeDef,
+    DeleteFleetAdvisorDatabasesResponseTypeDef,
     DeleteReplicationInstanceResponseTypeDef,
     DeleteReplicationTaskAssessmentRunResponseTypeDef,
     DeleteReplicationTaskResponseTypeDef,
@@ -67,6 +69,11 @@ from .type_defs import (
     DescribeEventCategoriesResponseTypeDef,
     DescribeEventsResponseTypeDef,
     DescribeEventSubscriptionsResponseTypeDef,
+    DescribeFleetAdvisorCollectorsResponseTypeDef,
+    DescribeFleetAdvisorDatabasesResponseTypeDef,
+    DescribeFleetAdvisorLsaAnalysisResponseTypeDef,
+    DescribeFleetAdvisorSchemaObjectSummaryResponseTypeDef,
+    DescribeFleetAdvisorSchemasResponseTypeDef,
     DescribeOrderableReplicationInstancesResponseTypeDef,
     DescribePendingMaintenanceActionsResponseTypeDef,
     DescribeRefreshSchemasStatusResponseTypeDef,
@@ -83,6 +90,7 @@ from .type_defs import (
     DocDbSettingsTypeDef,
     DynamoDbSettingsTypeDef,
     ElasticsearchSettingsTypeDef,
+    EmptyResponseMetadataTypeDef,
     FilterTypeDef,
     GcpMySQLSettingsTypeDef,
     IBMDb2SettingsTypeDef,
@@ -107,6 +115,7 @@ from .type_defs import (
     RedshiftSettingsTypeDef,
     RefreshSchemasResponseTypeDef,
     ReloadTablesResponseTypeDef,
+    RunFleetAdvisorLsaAnalysisResponseTypeDef,
     S3SettingsTypeDef,
     StartReplicationTaskAssessmentResponseTypeDef,
     StartReplicationTaskAssessmentRunResponseTypeDef,
@@ -148,8 +157,10 @@ class BotocoreClientError(BaseException):
 class Exceptions:
     AccessDeniedFault: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
+    CollectorNotFoundFault: Type[BotocoreClientError]
     InsufficientResourceCapacityFault: Type[BotocoreClientError]
     InvalidCertificateFault: Type[BotocoreClientError]
+    InvalidOperationFault: Type[BotocoreClientError]
     InvalidResourceStateFault: Type[BotocoreClientError]
     InvalidSubnet: Type[BotocoreClientError]
     KMSAccessDeniedFault: Type[BotocoreClientError]
@@ -190,7 +201,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def add_tags_to_resource(
-        self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]
+        self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]
     ) -> Dict[str, Any]:
         """
         .
@@ -241,30 +252,30 @@ class DatabaseMigrationServiceClient(BaseClient):
         DatabaseName: str = ...,
         ExtraConnectionAttributes: str = ...,
         KmsKeyId: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         CertificateArn: str = ...,
         SslMode: DmsSslModeValueType = ...,
         ServiceAccessRoleArn: str = ...,
         ExternalTableDefinition: str = ...,
-        DynamoDbSettings: "DynamoDbSettingsTypeDef" = ...,
-        S3Settings: "S3SettingsTypeDef" = ...,
-        DmsTransferSettings: "DmsTransferSettingsTypeDef" = ...,
-        MongoDbSettings: "MongoDbSettingsTypeDef" = ...,
-        KinesisSettings: "KinesisSettingsTypeDef" = ...,
-        KafkaSettings: "KafkaSettingsTypeDef" = ...,
-        ElasticsearchSettings: "ElasticsearchSettingsTypeDef" = ...,
-        NeptuneSettings: "NeptuneSettingsTypeDef" = ...,
-        RedshiftSettings: "RedshiftSettingsTypeDef" = ...,
-        PostgreSQLSettings: "PostgreSQLSettingsTypeDef" = ...,
-        MySQLSettings: "MySQLSettingsTypeDef" = ...,
-        OracleSettings: "OracleSettingsTypeDef" = ...,
-        SybaseSettings: "SybaseSettingsTypeDef" = ...,
-        MicrosoftSQLServerSettings: "MicrosoftSQLServerSettingsTypeDef" = ...,
-        IBMDb2Settings: "IBMDb2SettingsTypeDef" = ...,
+        DynamoDbSettings: DynamoDbSettingsTypeDef = ...,
+        S3Settings: S3SettingsTypeDef = ...,
+        DmsTransferSettings: DmsTransferSettingsTypeDef = ...,
+        MongoDbSettings: MongoDbSettingsTypeDef = ...,
+        KinesisSettings: KinesisSettingsTypeDef = ...,
+        KafkaSettings: KafkaSettingsTypeDef = ...,
+        ElasticsearchSettings: ElasticsearchSettingsTypeDef = ...,
+        NeptuneSettings: NeptuneSettingsTypeDef = ...,
+        RedshiftSettings: RedshiftSettingsTypeDef = ...,
+        PostgreSQLSettings: PostgreSQLSettingsTypeDef = ...,
+        MySQLSettings: MySQLSettingsTypeDef = ...,
+        OracleSettings: OracleSettingsTypeDef = ...,
+        SybaseSettings: SybaseSettingsTypeDef = ...,
+        MicrosoftSQLServerSettings: MicrosoftSQLServerSettingsTypeDef = ...,
+        IBMDb2Settings: IBMDb2SettingsTypeDef = ...,
         ResourceIdentifier: str = ...,
-        DocDbSettings: "DocDbSettingsTypeDef" = ...,
-        RedisSettings: "RedisSettingsTypeDef" = ...,
-        GcpMySQLSettings: "GcpMySQLSettingsTypeDef" = ...
+        DocDbSettings: DocDbSettingsTypeDef = ...,
+        RedisSettings: RedisSettingsTypeDef = ...,
+        GcpMySQLSettings: GcpMySQLSettingsTypeDef = ...
     ) -> CreateEndpointResponseTypeDef:
         """
         .
@@ -282,7 +293,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         EventCategories: Sequence[str] = ...,
         SourceIds: Sequence[str] = ...,
         Enabled: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateEventSubscriptionResponseTypeDef:
         """
         Creates an DMS event notification subscription.
@@ -291,6 +302,21 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#create_event_subscription)
         """
 
+    def create_fleet_advisor_collector(
+        self,
+        *,
+        CollectorName: str,
+        ServiceAccessRoleArn: str,
+        S3BucketName: str,
+        Description: str = ...
+    ) -> CreateFleetAdvisorCollectorResponseTypeDef:
+        """
+        Creates a Fleet Advisor collector using the specified parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.create_fleet_advisor_collector)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#create_fleet_advisor_collector)
+        """
+
     def create_replication_instance(
         self,
         *,
@@ -304,7 +330,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         MultiAZ: bool = ...,
         EngineVersion: str = ...,
         AutoMinorVersionUpgrade: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         KmsKeyId: str = ...,
         PubliclyAccessible: bool = ...,
         DnsNameServers: str = ...,
@@ -323,7 +349,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         ReplicationSubnetGroupIdentifier: str,
         ReplicationSubnetGroupDescription: str,
         SubnetIds: Sequence[str],
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateReplicationSubnetGroupResponseTypeDef:
         """
         Creates a replication subnet group given a list of the subnet IDs in a VPC.
@@ -345,7 +371,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         CdcStartTime: Union[datetime, str] = ...,
         CdcStartPosition: str = ...,
         CdcStopPosition: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         TaskData: str = ...,
         ResourceIdentifier: str = ...
     ) -> CreateReplicationTaskResponseTypeDef:
@@ -392,6 +418,26 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#delete_event_subscription)
         """
 
+    def delete_fleet_advisor_collector(
+        self, *, CollectorReferencedId: str
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the specified Fleet Advisor collector.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.delete_fleet_advisor_collector)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#delete_fleet_advisor_collector)
+        """
+
+    def delete_fleet_advisor_databases(
+        self, *, DatabaseIds: Sequence[str]
+    ) -> DeleteFleetAdvisorDatabasesResponseTypeDef:
+        """
+        Deletes the specified Fleet Advisor collector databases.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.delete_fleet_advisor_databases)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#delete_fleet_advisor_databases)
+        """
+
     def delete_replication_instance(
         self, *, ReplicationInstanceArn: str
     ) -> DeleteReplicationInstanceResponseTypeDef:
@@ -460,7 +506,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_certificates(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeCertificatesResponseTypeDef:
         """
         Provides a description of the certificate.
@@ -470,7 +516,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_connections(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeConnectionsResponseTypeDef:
         """
         Describes the status of the connections that have been made between the
@@ -492,7 +538,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_endpoint_types(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeEndpointTypesResponseTypeDef:
         """
         Returns information about the type of endpoints available.
@@ -502,7 +548,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_endpoints(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeEndpointsResponseTypeDef:
         """
         .
@@ -512,7 +558,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_event_categories(
-        self, *, SourceType: str = ..., Filters: Sequence["FilterTypeDef"] = ...
+        self, *, SourceType: str = ..., Filters: Sequence[FilterTypeDef] = ...
     ) -> DescribeEventCategoriesResponseTypeDef:
         """
         .
@@ -525,7 +571,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         self,
         *,
         SubscriptionName: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DescribeEventSubscriptionsResponseTypeDef:
@@ -545,7 +591,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         EndTime: Union[datetime, str] = ...,
         Duration: int = ...,
         EventCategories: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...
     ) -> DescribeEventsResponseTypeDef:
@@ -556,6 +602,58 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_events)
         """
 
+    def describe_fleet_advisor_collectors(
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeFleetAdvisorCollectorsResponseTypeDef:
+        """
+        Returns a list of the Fleet Advisor collectors in your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_fleet_advisor_collectors)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_fleet_advisor_collectors)
+        """
+
+    def describe_fleet_advisor_databases(
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeFleetAdvisorDatabasesResponseTypeDef:
+        """
+        Returns a list of Fleet Advisor databases in your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_fleet_advisor_databases)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_fleet_advisor_databases)
+        """
+
+    def describe_fleet_advisor_lsa_analysis(
+        self, *, MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeFleetAdvisorLsaAnalysisResponseTypeDef:
+        """
+        Provides descriptions of large-scale assessment (LSA) analyses produced by your
+        Fleet Advisor collectors.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_fleet_advisor_lsa_analysis)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_fleet_advisor_lsa_analysis)
+        """
+
+    def describe_fleet_advisor_schema_object_summary(
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeFleetAdvisorSchemaObjectSummaryResponseTypeDef:
+        """
+        Provides descriptions of the schemas discovered by your Fleet Advisor
+        collectors.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_fleet_advisor_schema_object_summary)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_fleet_advisor_schema_object_summary)
+        """
+
+    def describe_fleet_advisor_schemas(
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeFleetAdvisorSchemasResponseTypeDef:
+        """
+        Returns a list of schemas detected by Fleet Advisor Collectors in your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_fleet_advisor_schemas)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_fleet_advisor_schemas)
+        """
+
     def describe_orderable_replication_instances(
         self, *, MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeOrderableReplicationInstancesResponseTypeDef:
@@ -571,7 +669,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         self,
         *,
         ReplicationInstanceArn: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         Marker: str = ...,
         MaxRecords: int = ...
     ) -> DescribePendingMaintenanceActionsResponseTypeDef:
@@ -604,7 +702,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_replication_instances(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeReplicationInstancesResponseTypeDef:
         """
         Returns information about replication instances for your account in the current
@@ -615,7 +713,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_replication_subnet_groups(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeReplicationSubnetGroupsResponseTypeDef:
         """
         Returns information about the replication subnet groups.
@@ -636,7 +734,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_replication_task_assessment_runs(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeReplicationTaskAssessmentRunsResponseTypeDef:
         """
         Returns a paginated list of premigration assessment runs based on filter
@@ -647,7 +745,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         """
 
     def describe_replication_task_individual_assessments(
-        self, *, Filters: Sequence["FilterTypeDef"] = ..., MaxRecords: int = ..., Marker: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeReplicationTaskIndividualAssessmentsResponseTypeDef:
         """
         Returns a paginated list of individual assessments based on filter settings.
@@ -659,7 +757,7 @@ class DatabaseMigrationServiceClient(BaseClient):
     def describe_replication_tasks(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxRecords: int = ...,
         Marker: str = ...,
         WithoutSettings: bool = ...
@@ -687,7 +785,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         ReplicationTaskArn: str,
         MaxRecords: int = ...,
         Marker: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...
+        Filters: Sequence[FilterTypeDef] = ...
     ) -> DescribeTableStatisticsResponseTypeDef:
         """
         Returns table statistics on the database migration task, including table name,
@@ -717,7 +815,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         CertificateIdentifier: str,
         CertificatePem: str = ...,
         CertificateWallet: Union[str, bytes, IO[Any], StreamingBody] = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> ImportCertificateResponseTypeDef:
         """
         Uploads the specified certificate.
@@ -753,25 +851,25 @@ class DatabaseMigrationServiceClient(BaseClient):
         SslMode: DmsSslModeValueType = ...,
         ServiceAccessRoleArn: str = ...,
         ExternalTableDefinition: str = ...,
-        DynamoDbSettings: "DynamoDbSettingsTypeDef" = ...,
-        S3Settings: "S3SettingsTypeDef" = ...,
-        DmsTransferSettings: "DmsTransferSettingsTypeDef" = ...,
-        MongoDbSettings: "MongoDbSettingsTypeDef" = ...,
-        KinesisSettings: "KinesisSettingsTypeDef" = ...,
-        KafkaSettings: "KafkaSettingsTypeDef" = ...,
-        ElasticsearchSettings: "ElasticsearchSettingsTypeDef" = ...,
-        NeptuneSettings: "NeptuneSettingsTypeDef" = ...,
-        RedshiftSettings: "RedshiftSettingsTypeDef" = ...,
-        PostgreSQLSettings: "PostgreSQLSettingsTypeDef" = ...,
-        MySQLSettings: "MySQLSettingsTypeDef" = ...,
-        OracleSettings: "OracleSettingsTypeDef" = ...,
-        SybaseSettings: "SybaseSettingsTypeDef" = ...,
-        MicrosoftSQLServerSettings: "MicrosoftSQLServerSettingsTypeDef" = ...,
-        IBMDb2Settings: "IBMDb2SettingsTypeDef" = ...,
-        DocDbSettings: "DocDbSettingsTypeDef" = ...,
-        RedisSettings: "RedisSettingsTypeDef" = ...,
+        DynamoDbSettings: DynamoDbSettingsTypeDef = ...,
+        S3Settings: S3SettingsTypeDef = ...,
+        DmsTransferSettings: DmsTransferSettingsTypeDef = ...,
+        MongoDbSettings: MongoDbSettingsTypeDef = ...,
+        KinesisSettings: KinesisSettingsTypeDef = ...,
+        KafkaSettings: KafkaSettingsTypeDef = ...,
+        ElasticsearchSettings: ElasticsearchSettingsTypeDef = ...,
+        NeptuneSettings: NeptuneSettingsTypeDef = ...,
+        RedshiftSettings: RedshiftSettingsTypeDef = ...,
+        PostgreSQLSettings: PostgreSQLSettingsTypeDef = ...,
+        MySQLSettings: MySQLSettingsTypeDef = ...,
+        OracleSettings: OracleSettingsTypeDef = ...,
+        SybaseSettings: SybaseSettingsTypeDef = ...,
+        MicrosoftSQLServerSettings: MicrosoftSQLServerSettingsTypeDef = ...,
+        IBMDb2Settings: IBMDb2SettingsTypeDef = ...,
+        DocDbSettings: DocDbSettingsTypeDef = ...,
+        RedisSettings: RedisSettingsTypeDef = ...,
         ExactSettings: bool = ...,
-        GcpMySQLSettings: "GcpMySQLSettingsTypeDef" = ...
+        GcpMySQLSettings: GcpMySQLSettingsTypeDef = ...
     ) -> ModifyEndpointResponseTypeDef:
         """
         .
@@ -890,7 +988,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         self,
         *,
         ReplicationTaskArn: str,
-        TablesToReload: Sequence["TableToReloadTypeDef"],
+        TablesToReload: Sequence[TableToReloadTypeDef],
         ReloadOption: ReloadOptionValueType = ...
     ) -> ReloadTablesResponseTypeDef:
         """
@@ -910,6 +1008,15 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#remove_tags_from_resource)
         """
 
+    def run_fleet_advisor_lsa_analysis(self) -> RunFleetAdvisorLsaAnalysisResponseTypeDef:
+        """
+        Runs large-scale assessment (LSA) analysis on every Fleet Advisor collector in
+        your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.run_fleet_advisor_lsa_analysis)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#run_fleet_advisor_lsa_analysis)
+        """
+
     def start_replication_task(
         self,
         *,
