@@ -110,8 +110,8 @@ class DescribeCertificatesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeCertificatesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeCertificates.paginate)
@@ -128,8 +128,8 @@ class DescribeConnectionsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeConnectionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeConnections.paginate)
@@ -146,8 +146,8 @@ class DescribeEndpointTypesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEndpointTypesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEndpointTypes.paginate)
@@ -164,8 +164,8 @@ class DescribeEndpointsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEndpointsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEndpoints.paginate)
@@ -183,8 +183,8 @@ class DescribeEventSubscriptionsPaginator(Boto3Paginator):
         self,
         *,
         SubscriptionName: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEventSubscriptionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEventSubscriptions.paginate)
@@ -207,8 +207,8 @@ class DescribeEventsPaginator(Boto3Paginator):
         EndTime: Union[datetime, str] = ...,
         Duration: int = ...,
         EventCategories: Sequence[str] = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEventsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeEvents.paginate)
@@ -223,7 +223,7 @@ class DescribeOrderableReplicationInstancesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeOrderableReplicationInstancesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeOrderableReplicationInstances.paginate)
@@ -240,8 +240,8 @@ class DescribeReplicationInstancesPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeReplicationInstancesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationInstances.paginate)
@@ -258,8 +258,8 @@ class DescribeReplicationSubnetGroupsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeReplicationSubnetGroupsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationSubnetGroups.paginate)
@@ -274,7 +274,7 @@ class DescribeReplicationTaskAssessmentResultsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, ReplicationTaskArn: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ReplicationTaskArn: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeReplicationTaskAssessmentResultsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationTaskAssessmentResults.paginate)
@@ -291,9 +291,9 @@ class DescribeReplicationTasksPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         WithoutSettings: bool = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeReplicationTasksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeReplicationTasks.paginate)
@@ -308,7 +308,7 @@ class DescribeSchemasPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, EndpointArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, EndpointArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeSchemasResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeSchemas.paginate)
@@ -326,8 +326,8 @@ class DescribeTableStatisticsPaginator(Boto3Paginator):
         self,
         *,
         ReplicationTaskArn: str,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[FilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeTableStatisticsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Paginator.DescribeTableStatistics.paginate)
